#ifndef OIDC_LIST_H
#define OIDC_LIST_H

#ifndef USE_LIST_SO
#include "list/list.h"
#else
#include <clibs/list.h>
#endif /* USE_LIST_SO */

#endif /* OIDC_LIST_H */
